@@ -472,13 +472,11 @@ class MusePointings(SofPipe, PipeRecipes):
                 upipe.print_error(f"Format of input table not recognised")
 
         if not hasattr(self, 'pointing_table'):
-            print("COUCOU")
-            print(input_table)
             self.pointing_table = self.get_pointing_table()
 
         # Now replace names with pixel tables names
         else:
-            if self._pixtab_in_comb_folder
+            if self._pixtab_in_comb_folder:
                 qtable_pixtables = self.get_qtable()
                 for row in self.pointing_table.qtable:
                     dataset = row['dataset']
@@ -519,9 +517,11 @@ class MusePointings(SofPipe, PipeRecipes):
     def dict_pixtabs_in_pointings(self):
         return self.pointing_table.dict_names_in_pointings
 
+    @property
     def dict_tplexpo_per_dataset(self):
         return self.pointing_table.dict_tplexpo_per_dataset
 
+    @property
     def dict_tplexpo_per_pointing(self):
         return self.pointing_table.dict_tplexpo_per_pointing
 
